<?php 
namespace Magecomp\Restrictpaymentbyship\Model;

use Magecomp\Restrictpaymentbyship\Api\PostManagementInterface;
use Magento\Payment\Api\PaymentMethodListInterface;
use Magento\Framework\Exception\AuthenticationException;
use Magento\Framework\App\ObjectManager;
use Magento\Config\Model\ResourceModel\Config;

class PostManagement implements PostManagementInterface{
    public $paymentMethodList;
    protected $_shippingConfig;

    public function __construct(
        PaymentMethodListInterface $paymentMethodList,
        Config $config,
        \Magento\Framework\App\Config\Storage\WriterInterface $configWriter,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Shipping\Model\Config $shipconfig
       
    )  {
        $this->paymentMethodList = $paymentMethodList;
        $this->config = $config;
        $this->_configWriter = $configWriter;
        $this->shipconfig = $shipconfig;
        $this->scopeConfig = $scopeConfig;
    }
        
    public function setRestrictPayment($shippingmethod, $paymentmethod, $storeid)
    {
        try {
            $availableMethods = [];
            $flag = 0;
            foreach ($this->getActivePayment($storeid) as $method) {
                $availableMethods[] = $method->getCode();
            }
            foreach ($availableMethods as $key => $method) {
                if (in_array($paymentmethod, $availableMethods) && in_array($shippingmethod,$this->getActiveShippingList())) {
                    unset($availableMethods[$key]);
                    $flag = 1;
                    $removedmethod = $method;
                    $outputPath = "payment/".$removedmethod."/active";
                    $this->config->saveConfig($outputPath,true,'default',0);
                }
            }
            if ($flag) {
                return ['status'=>true, 'message'=>"Method Removed."];
            }
            return['status'=>false, 'message'=>"Invalid parameter."];
        } catch (\Exception $e) {
            throw new AuthenticationException($e->getMessage());
            return ['status' => false, 'message' =>$e];
        }
    }

    public function getActivePayment($storeid)
    {
        $activePaymentMethodList = $this->paymentMethodList->getActiveList($storeid) ;
        return $activePaymentMethodList;
    }
    public function getActiveShippingList()
    {
        $activeCarriers = $this->shipconfig->getActiveCarriers();
        $shippingmethods = array();
        foreach($activeCarriers as $carrierCode => $carrierModel)
        {
            $options = array();
            if($carrierMethods = $carrierModel->getAllowedMethods())
            {
                foreach ($carrierMethods as $methodCode => $method)
                {
                    $code = $carrierCode.'_'.$methodCode;
                    $options[]= array('value'=>$code,'label'=>$method);
                }
                $carrierTitle = $this->scopeConfig->getValue('carriers/'.$carrierCode.'/title');

            }
            $shippingmethods[]=$carrierTitle; 

        }

        return $shippingmethods;
    }
}

